@@ -52,18 +52,8 @@ class IsSome a b where
   default maybeFrom :: (IsSome b a) => a -> Maybe b
   maybeFrom = Just . to
 
--- | Every type is isomorphic to itself.
-instance IsSome a a where
-  to = id
-  maybeFrom = Just . id
-
--- | The empty set has no elements, and therefore is vacuously a subset of any set.
-instance IsSome a Void where
-  to = absurd
-  maybeFrom = const Nothing
-
 -- |
--- Convert a value of a superset type to a subset type specifying the superset type first.
+-- Convert a value of a subset type to a superset type, specifying the source subset type first.
 --
 -- Alias to 'to' with the only difference in the argument order.
 --
@@ -108,7 +98,7 @@ maybeTo = maybeFrom
 --
 -- Every value of type @b@ can be obtained by applying 'onfrom' to some value of type @a@:
 --
--- > \b -> exists a. onfrom @b a == b
+-- > \b -> exists a. onfrom @a @b a == b
 --
 -- Note: This property cannot be directly tested with QuickCheck as it requires existential quantification.
 --
@@ -158,8 +148,6 @@ class (IsSome a b) => IsMany a b where
 onto :: forall b a. (IsMany a b) => a -> b
 onto = onfrom
 
-instance IsMany a a
-
 -- | Bidirectional conversion between two types with no loss of information.
 --
 -- The bidirectionality is encoded via a recursive dependency with arguments
@@ -173,13 +161,13 @@ instance IsMany a a
 --
 -- For all values of /b/ converting from /b/ to /a/ and then converting from /a/ to /b/ produces the original value:
 --
--- > \b -> b == from @b (to @a b)
+-- > \b -> b == from @a (to @a b)
 --
 -- ==== 'to' is an [inverse](https://en.wikipedia.org/wiki/Inverse_function) of 'from'
 --
 -- For all values of /a/ converting from /a/ to /b/ and then converting from /b/ to /a/ produces the original value:
 --
--- > \a -> a == to @a (from @b a)
+-- > \a -> a == to @a (from @a @b a)
 --
 -- ==== Mathematical relationship
 --
@@ -190,7 +178,7 @@ instance IsMany a a
 --
 -- For isomorphic types, both ways of converting should be equivalent:
 --
--- > \a -> from @b @a a == onfrom @a @b a
+-- > \a -> from @a @b a == onfrom @a @b a
 --
 -- === Testing
 --
@@ -220,6 +208,3 @@ instance IsMany a a
 -- instance Is "Data.Text.Text" "Data.Text.Lazy.LazyText"
 -- @
 class (IsMany a b, Is b a) => Is a b
-
--- | Any type is isomorphic to itself.
-instance Is a a
