@@ -16,4 +16,4 @@ instance IsSome ByteString Data.Text.Lazy.Text where
 
 -- | Lenient UTF-8 decoding.
 instance IsMany ByteString Data.Text.Lazy.Text where
-  from = Data.Text.Lazy.Encoding.decodeUtf8With Data.Text.Encoding.Error.lenientDecode . Data.ByteString.Lazy.fromStrict
+  onfrom = Data.Text.Lazy.Encoding.decodeUtf8With Data.Text.Encoding.Error.lenientDecode . Data.ByteString.Lazy.fromStrict
